import test, { describe } from "node:test";
import assert from "node:assert";
import Vault from "../vault.js";

describe("Vault", () => {
  test("load a vault", () => {
    const vault = new Vault("./bin/_test/test-vault");
    assert.equal(vault.size, 4, "Unexpected number of documents in vault");
  });

  test("ignore paths", () => {
    const vault = new Vault("./bin/_test/test-vault", {
      ignorePatterns: ["**/Ignoreme/**"],
    });
    assert.equal(vault.size, 3, "Unexpected number of documents in vault");
  });

  test("reading tags", () => {
    const vault = new Vault("./bin/_test/test-vault");
    const taggedFile = vault.index["directory-subdirectory-i-have-tags"];

    if (taggedFile === undefined) {
      assert.fail("Expected file with tags");
    }

    const expectedTags = ["propertytag", "tags", "hashtags"];
    assert.deepStrictEqual(taggedFile.tags, expectedTags);
  });
});
